#ifndef _SHARE_H
#define _SHARE_H

#ifndef _READCONF_H
#include "readconf.h"
#endif

#define SHARE_STAT_NEW		0
#define SHARE_STAT_OLD		1
#define SHARE_STAT_DEL		2
#define SHARE_STAT_UPD		3	/* updated - send delete & new to server */

#define SHARE_TYPE_UNKNOWN	0
#define SHARE_TYPE_MP3		1
#define SHARE_TYPE_OGG		2


struct sharestruct {
	struct sharestruct *prev;
	struct sharestruct *next;
	int id;
	uint32 hash;	/* crc32 of path+file */
	unsigned char status;

	/* file info */
	unsigned char *path;
	unsigned char *file;
	unsigned char *file_hash;
	unsigned int size;
	time_t lastmod;

	/* stuff we got from the server */
	int fileid_len;
	unsigned char *fileid;
	int server_id;
	int song_id;

	short bitrate;
	int seclength;

	/* ID3v1 */
	unsigned char have_id3v1;
	unsigned char *id3v1_title;
	unsigned char *id3v1_artist;
	unsigned char *id3v1_album;

	/* ID3v2 */
	unsigned char have_id3v2;
	unsigned char *id3v2_title;
	unsigned char *id3v2_artist;
	unsigned char *id3v2_album;
	short id3v2_track;

	/* bam */
	int is_download;
	int download_speed;
	/* TODO: add timeout thingy? just to make sure the event is always triggered.. */
};

extern struct sharestruct *sharelist;
extern int old_shares, new_shares, upd_shares, del_shares, shared, save_share_db;

int share_save_db();
int share_load_db();
void share_interval_save_db();
int path_is_shared(unsigned char *path);
int get_file_type(unsigned char *file);
int share_get_md5_hash(struct sharestruct *s);
void share_dir(unsigned char *path, int depth);
void share_status();
unsigned long share_make_hash(unsigned char *path, unsigned char *file);
struct sharestruct *share_find_by_id(int id);
struct sharestruct *share_find_by_fileid(unsigned char *fileid, int fileid_len);
struct sharestruct *share_new();
void share_wash(struct sharestruct *s);
void share_del(struct sharestruct *share);
void share_free();
void share_list(struct confshare *s);

/*
#define FREAD_DUMMY_INT(int) \
	if(fseek(fd, sizeof(int), SEEK_CUR) == -1) { err = 1; break; };

#define FREAD_DUMMY_STR(str) \
	if(fread(&len, sizeof(len), 1, fd) == 0) { err = 1; break; } \
	if(fseek(fd, len, SEEK_CUR) == -1) { err = 1; break; } \
*/

#endif
