#include "config.h"
#include "macros.h"


/* share.c helper functions */

void FWRITE_UINT32(FILE *fd, int *err, uint32 v)
{
	if(*err) return;

	if(fwrite(&v, sizeof(v), 1, fd) != 1)
		*err = 1;
	return;
}

void FWRITE_BYTE(FILE *fd, int *err, unsigned char v)
{
	if(*err) return;

	if(fwrite(&v, sizeof(v), 1, fd) != 1)
		*err = 1;
	return;
}

void FWRITE_SHORT(FILE *fd, int *err, short v)
{
	if(*err) return;

	if(fwrite(&v, sizeof(v), 1, fd) != 1)
		*err = 1;
	return;
}

void FWRITE_INT(FILE *fd, int *err, int v)
{
	if(*err) return;

	if(fwrite(&v, sizeof(v), 1, fd) != 1)
		*err = 1;
	return;
}

void FWRITE_STR(FILE *fd, int *err, unsigned char *str)
{
	short len;

	if(*err) return;

	if(str) {
		len = strlen(str);
		if(fwrite(&len, sizeof(len), 1, fd) != 1)
		{
			*err = 1;
			return;
		}
		if(fwrite(str, len, 1, fd) != 1)
			*err = 1;
	} else {
		len = 0;
		if(fwrite(&len, sizeof(len), 1, fd) != 1)
			*err = 1;
	}

	return;
}

void FWRITE_BIN(FILE *fd, int *err, unsigned char *str, short len)
{
	if(*err) return;

	if(str) {
		if(fwrite(&len, sizeof(len), 1, fd) != 1)
		{
			*err = 1;
			return;
		}
		if(fwrite(str, len, 1, fd) != 1)
			*err = 1;
	} else {
		len = 0;
		if(fwrite(&len, sizeof(len), 1, fd) != 1)
			*err = 1;
	}

	return;
}


uint32 FREAD_UINT32(FILE *fd, int *err)
{
	uint32 v;

	if(*err) return 0;

	if(fread(&v, sizeof(v), 1, fd) != 1)
		*err = 1;

	return v;
}

unsigned char FREAD_BYTE(FILE *fd, int *err)
{
	unsigned char v;

	if(*err) return 0;

	if(fread(&v, sizeof(v), 1, fd) != 1)
		*err = 1;

	return v;
}

short FREAD_SHORT(FILE *fd, int *err)
{
	short v;

	if(*err) return 0;

	if(fread(&v, sizeof(v), 1, fd) != 1)
		*err = 1;

	return v;
}

int FREAD_INT(FILE *fd, int *err)
{
	int v;

	if(*err) return 0;

	if(fread(&v, sizeof(v), 1, fd) != 1)
		*err = 1;

	return v;
}

unsigned char *FREAD_STR(FILE *fd, int *err)
{
	unsigned char *str;
	short len;

	if(*err) return NULL;

	/* get string length */
	if(fread(&len, sizeof(len), 1, fd) != 1)
	{
		*err = 1;
		return NULL;
	}

	if(len == 0)
	{
		/* empty string.. */
		return NULL;
	}
	else
	{
		/* check for weird lengths */
		if(len < 0 || len > 1024)
		{
			NOTICE("sharedb error - too large/small string (%d)", len);
			*err = 1;
			return NULL;
		}

		str = ag_malloc(len+1);
		if(!str)
		{
			*err = 1;
			return NULL;
		}
		if(fread(str, len, 1, fd) != 1)
		{
			*err = 1;
			ag_free(str);
			return NULL;
		}
		str[len] = 0;
	}

	return str;
}

unsigned char *FREAD_BIN(FILE *fd, int *err, int *rlen)
{
	unsigned char *str;
	short len;

	if(*err) return NULL;

	/* get binary string length */
	if(fread(&len, sizeof(len), 1, fd) != 1)
	{
		*err = 1;
		return NULL;
	}

	if(rlen)
		*rlen = len;

	if(len == 0)
	{
		/* empty binary string */
		return NULL;
	}
	else
	{
		/* check for weird lengths */
		if(len < 0 || len > 1024)
		{
			NOTICE("sharedb error - too large/small string (%d)", len);
			*err = 1;
			return NULL;
		}

		str = ag_malloc(len);
		if(!str)
		{
			*err = 1;
			return NULL;
		}
		if(fread(str, len, 1, fd) != 1)
		{
			*err = 1;
			ag_free(str);
			return NULL;
		}
	}

	return str;
}
